﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Runtime.InteropServices;


namespace ZDCloudAPISharp
{
    class ZDCloudAPI
    {
        static ZDCloudAPI()
        {
            string zdcloudPath = System.IO.Path.GetDirectoryName(System.IO.Path.GetDirectoryName(System.Windows.Forms.Application.StartupPath));
            string pathlist = Environment.GetEnvironmentVariable("Path", EnvironmentVariableTarget.Process).Trim(';');
            Environment.SetEnvironmentVariable("Path", zdcloudPath + ";" + pathlist, EnvironmentVariableTarget.Process);
        }

        /// <summary>
        /// 回调方法用于之多云主动通知应用
        /// </summary>
        /// <returns>void</returns>
        /// <param name="type">[out] int type: 0:登录 1:退出 2:注销</param>
        public delegate void ZDCloudAPICallBack(int type);

        /// <summary>
        /// 初始化方法
        /// </summary>
        /// <returns>int类型，0：成功初始化；1：appkey错误；2：seckey错误；其他数字，其他错误</returns>
        /// <param name="appkey">应用的appkey</param>
        /// <param name="seckey">应用的seckey</param>
        /// <param name="zdccb">回调方法，当之多云有相应消息的时候主动通知应用，null则不接受回调</param>
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern int Initial(string appkey, string seckey, ZDCloudAPICallBack zdccb);

        /// <summary>
        /// 初始化方法
        /// </summary>
        /// <returns>int类型，0：成功初始化；1：appkey错误；2：seckey错误；其他数字，其他错误</returns>
        /// <param name="appkey">应用的appkey</param>
        /// <param name="seckey">应用的seckey</param>
        public static int Initial(string appkey, string seckey)
        {
            return Initial(appkey, seckey, null);
        }

        /// <summary>
        ///释放接口， 在应用退出前调用
        /// </summary>
        /// <returns>void</returns>
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern void UnInitial();

        /// <summary>
        /// 获取用户登陆信息
        /// </summary>
        /// <param name="uid">out 用户id 缓冲区32</param>
        /// <param name="nick">out 用户昵称 缓冲区128</param>
        /// <param name="zdck">out 用户授权key 缓冲区256</param>
        /// <returns>	0:已登录,uid,nick,zdck已复制到缓冲区 1:之多云没有登录 2:App尚未初始化 其他值:其他错误代码</returns>        
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern int GetLoginInfo(StringBuilder uid, StringBuilder nick, StringBuilder zdck);

        /// <summary>
        /// 登录
        /// </summary>
        /// <returns>void,之多云会尝试自动登陆</returns>
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern void Login();

        /// <summary>
        /// 新建下载任务
        /// </summary>
        /// <returns>void</returns>
        /// <param name="url">下载的url</param>
        /// <param name="FileName">默认保存的文件名</param>
        /// <param name="Path">默认保存路径，若留空则使用之多云默认保存路径</param>
        /// <param name="bShowWindow">bool,是否显示新建下载对话框，true：显示新建对话框；false： 不显示新建对话框</param>
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern void NewDownload(string url, string FileName, string Path, [MarshalAs(UnmanagedType.Bool)] bool bShowWindow);

        /// <summary>
        /// 新建下载任务
        /// </summary>
        /// <returns>void</returns>
        /// <param name="url">下载的url</param>
        /// <param name="FileName">默认保存的文件名</param>
        /// <param name="Path">默认保存路径，若留空则使用之多云默认保存路径</param>
        public static void NewDownload(string url, string FileName = "", string Path = "")
        {
            NewDownload(url, FileName, Path, false);
        }

        /// <summary>
        /// 显示之多云下载管理器
        /// </summary>
        /// <returns>void</returns>
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern void ShowDownloadMgr();

        /// <summary>
        /// 之多云TTS打断朗读
        /// </summary>        
        /// <param name="Text">需要朗读的文本字符串 缓冲区最大为4000</param>
        /// <param name="bWindowChangedStop">切换窗口时打断本次朗读</param>
        /// <returns>0:成功 1:App尚未初始化 2:text为NULL或长度大于4000</returns>
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern int SpeakAsync(string text, [MarshalAs(UnmanagedType.Bool)]bool bWindowChangedStop);

        /// <summary>
        /// 之多云TTS插入朗读
        /// </summary>
        /// <param name="Text">要朗读的文本,缓冲区最大为255</param>
        /// <param name="bWindowChangedStop">切换窗口时打断本次朗读</param>
        /// <returns>0:成功 1:App尚未初始化 2:text为NULL或长度大于255</returns>
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern int SpeakInsert(string text, [MarshalAs(UnmanagedType.Bool)]bool bWindowChangedStop);

        /// <summary>
        /// 之多云TTS尝试朗读
        /// </summary>
        /// <param name="text">要朗读的文本,缓冲区最大为4000</param>
        /// <param name="bWindowChangedStop">切换窗口时打断本次朗读</param>		
        /// <returns>0:成功 1:App尚未初始化 2:text为NULL或长度大于4000 3:当之多云正在朗读时,尝试朗读失败</returns>
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern int SpeakTry(string text, [MarshalAs(UnmanagedType.Bool)]bool bWindowChangedStop);

        /// <summary>
        /// 之多云TTS停止朗读
        /// </summary>
        /// <returns></returns>
        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern void StopSpeak();

        [DllImport("ZDCloudAPI.dll", CharSet = CharSet.Unicode)]
        public static extern void ExcuteScript(int type, string script);

    }
}
